<?php if ( ! defined( 'ABSPATH' ) ) { die( 'Direct access forbidden.' ); }
/**
 * Theme Configuration and Custom CSS initializtion
 */

/**
 * Global theme config for header/footer/sections/colors/fonts
 */
if ( !function_exists('homefort_theme_config') ) {

	add_filter( 'lte_get_theme_config', 'homefort_theme_config', 10, 1 );
	function homefort_theme_config() {

	    return array(
	    	/**
	    	 * Format of navbar
	    	 * layout-navbar-class-color
	    	 * color represents the text/links/icons color (black/white)
	    	 */
	    	'navbar'	=>	array(
				'default-black'  						=> esc_html__( 'Classic Light', 'homefort' ),
				'default-white'  						=> esc_html__( 'Classic Dark', 'homefort' ),
				'transparent-black'  					=> esc_html__( 'Classic Semi-Transparent on Light', 'homefort' ),
				'transparent-white'  					=> esc_html__( 'Classic Semi-Transparent on Dark', 'homefort' ),
				'transparent-full-black'  				=> esc_html__( 'Classic Transparent on Light', 'homefort' ),
				'transparent-full-white'  				=> esc_html__( 'Classic Transparent on Dark', 'homefort' ),
				'pattern-white'  						=> esc_html__( 'Background Pattern Dark', 'homefort' ),
			),
			'navbar-default' => 'default-black',

			'footer' => array(
				'default'  => esc_html__( 'Default', 'homefort' ),		
				'copyright'  => esc_html__( 'Copyright Only', 'homefort' ),
				'copyright-transparent'  => esc_html__( 'Copyright Transparent', 'homefort' ),						
			),
			'footer-default' => 'default',

			'color_main'	=>	'#f35d22',
			'color_second'	=>	'#f35d22',
			'color_gray'	=>	'#f7f2ed',
			'color_black'	=>	'#0f2c49',
			'color_white'	=>	'#FFFFFF',
			'color_red'		=>	'#f6520a',
			'color_green'	=>	'#42bf80',
			'color_yellow'	=>	'#ebbc4a',
			
			'color_main_header'	=>	esc_html__( 'Yellow', 'homefort' ),

			'logo_height'		=>	58,
			'navbar_dark'		=>	'rgba(0,0,0,0.75)',

			'font_main'					=>	'Open Sans',
			'font_main_var'				=>	'regular',
			'font_main_weights'			=>	'400,400i,600i,600,700,700i',
			'font_headers'				=>	'Barlow',
			'font_headers_var'			=>	'regular',
			'font_headers_weights'		=>	'600,700',
			'font_subheaders'			=>	'',
			'font_subheaders_var'		=>	'',
			'font_subheaders_weights'	=>	'',
		);
	}
}

/**
 *  Editor Settings
 */
function homefort_editor_settings() {

	$cfg = homefort_theme_config();

    add_theme_support( 'editor-color-palette', array(
        array(
            'name' => esc_html__( 'Main', 'homefort' ),
            'slug' => 'main-theme',
            'color' => $cfg['color_main'],
        ),
        array(
            'name' => esc_html__( 'Gray', 'homefort' ),
            'slug' => 'gray',
            'color' => $cfg['color_gray'],
        ),
        array(
            'name' => esc_html__( 'Black', 'homefort' ),
            'slug' => 'black',
            'color' => $cfg['color_black'],
        ),    
        array(
            'name' => esc_html__( 'Pale Pink', 'homefort' ),
            'slug' => 'pale-pink',
            'color' => '#f78da7',
        ),                
    ) );

	add_theme_support( 'editor-font-sizes', array(
		array(
			'name'      => esc_html__( 'small', 'homefort' ),
			'shortName' => esc_html__( 'S', 'homefort' ),
			'size'      => 14,
			'slug'      => 'small'
		),
		array(
			'name'      => esc_html__( 'regular', 'homefort' ),
			'shortName' => esc_html__( 'M', 'homefort' ),
			'size'      => 16,
			'slug'      => 'regular'
		),
		array(
			'name'      => esc_html__( 'large', 'homefort' ),
			'shortName' => esc_html__( 'L', 'homefort' ),
			'size'      => 24,
			'slug'      => 'large'
		),
	) );    
}
add_action( 'after_setup_theme', 'homefort_editor_settings', 10 );

/**
 * Get Google default font url
 */
if ( !function_exists('homefort_font_url') ) {

	function homefort_font_url() {

		$cfg = homefort_theme_config();
		$q = array();
		foreach ( array('font_main', 'font_headers', 'font_subheaders') as $item ) {

			if ( !empty($cfg[$item]) ) {

				$w = '';
				if ( !empty($cfg[$item.'_weights']) ) {

					$w .= ':'.$cfg[$item.'_weights'];
				}
				$q[] = $cfg[$item].$w;
			}
		}

		$query_args = array( 'family' => implode('%7C', $q), 'subset' => 'latin' );

		$font_url = add_query_arg( $query_args, '//fonts.googleapis.com/css' );

		return esc_url( $font_url );
	}
}

/**
 * Config used for lt-ext plugin to set Visual Composer configuration
 */
if ( !function_exists('homefort_vc_config') ) {

	add_filter( 'lte_elementor_config', 'homefort_elementor_config', 10, 1 );
	function homefort_elementor_config( $value ) {

	    return array(
	    	'sections'	=>	array(
			),
			'background' => array(
				"main" 		=>	esc_html__( "Main", 'homefort' ),	
				"second"	=>	esc_html__( "Second", 'homefort' ),	
				"black"		=>	esc_html__( "Black", 'homefort' ),
				"gray"		=>	esc_html__( "Gray", 'homefort' ),
				"white"		=>	esc_html__( "White", 'homefort' ),
			),
			'overlay'	=> array(
				"semi-dark"		=>	esc_html__( "Light Overlay (25%)", 'homefort' ),
				"semi-black"		=>	esc_html__( "Semi-Black Overlay (40%)", 'homefort' ),
				"black"			=>	esc_html__( "Black Overlay (90%)", 'homefort' ),
				"gradient-hor"	=>	esc_html__( "Horizontal Gradient", 'homefort' ),			
				"white"			=>	esc_html__( "White Overlay (40%)", 'homefort' ),
				"gray-bg"		=>	esc_html__( "Gray Waves Background", 'homefort' ),
			),
		);
	}
}


/*
* Adding additional TinyMCE options
*/
if ( !function_exists('homefort_mce_before_init_insert_formats') ) {

	add_filter('mce_buttons_2', 'homefort_wpb_mce_buttons_2');
	function homefort_wpb_mce_buttons_2( $buttons ) {

	    array_unshift($buttons, 'styleselect');
	    return $buttons;
	}

	add_filter( 'tiny_mce_before_init', 'homefort_mce_before_init_insert_formats' );
	function homefort_mce_before_init_insert_formats( $init_array ) {  

	    $style_formats = array(

	        array(  
	            'title' => esc_html__('Main Color', 'homefort'),
	            'block' => 'span',  
	            'classes' => 'color-main',
	            'wrapper' => true,
	        ),  
	        array(  
	            'title' => esc_html__('White Color', 'homefort'),
	            'block' => 'span',  
	            'classes' => 'color-white',
	            'wrapper' => true,   
	        ),        
	        array(  
	            'title' => esc_html__('Medium Text', 'homefort'),
	            'block' => 'span',  
	            'classes' => 'text-md',
	            'wrapper' => true,   
	        ),
	        array(  
	            'title' => esc_html__('Large Text', 'homefort'),
	            'block' => 'span',  
	            'classes' => 'text-lg',
	            'wrapper' => true,   
	        ),	  	        
	        array(  
	            'title' => esc_html__('Checkbox List', 'homefort'),
	            'selector' => 'ul',  
	            'classes' => 'check',
	        ),		        
	    );  
	    $init_array['style_formats'] = json_encode( $style_formats );  
	     
	    return $init_array;  
	} 
}


/**
 * Register widget areas.
 *
 */
if ( !function_exists('homefort_action_theme_widgets_init') ) {

	add_action( 'widgets_init', 'homefort_action_theme_widgets_init' );
	function homefort_action_theme_widgets_init() {

		$span_class = 'widget-icon';

		$header_class = $theme_icon = '';
		if ( function_exists('FW') ) {

			$theme_icon = fw_get_db_settings_option( 'theme-icon-main' );
			if ( !empty($theme_icon['icon-class']) ) {

				$header_class = 'hasIcon';
				$span_class .=  ' ' . $theme_icon['icon-class'];
			}
		}
			else {

			$span_class = '';
		}

		register_sidebar( array(
			'name'          => esc_html__( 'Sidebar Default', 'homefort' ),
			'id'            => 'sidebar-1',
			'description'   => esc_html__( 'Displayed in the right/left section of the site.', 'homefort' ),
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget'  => '</aside>',
			'before_title'  => '<div class="lte-sidebar-header"><h3 class="lte-header-widget '.esc_attr($header_class).'"><span class="'.esc_attr($span_class).'"></span>',
			'after_title'   => '</h3></div>',
		) );

		register_sidebar( array(
			'name'          => esc_html__( 'Sidebar WooCommerce', 'homefort' ),
			'id'            => 'sidebar-wc',
			'description'   => esc_html__( 'Displayed in the right/left section of the site.', 'homefort' ),
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget'  => '</aside>',
			'before_title'  => '<div class="lte-sidebar-header"><h3 class="lte-header-widget '.esc_attr($header_class).'"><span class="'.esc_attr($span_class).'"></span>',
			'after_title'   => '</h3></div>',
		) );

		if ( function_exists('FW') ) {

			register_sidebar( array(
				'name'          => esc_html__( 'Footer 1', 'homefort' ),
				'id'            => 'footer-1',
				'description'   => esc_html__( 'Displayed in the footer section of the site.', 'homefort' ),
				'before_widget' => '<div id="%1$s" class="widget %2$s">',
				'after_widget'  => '</div>',
				'before_title'  => '<h3 class="lte-header-widget '.esc_attr($header_class).'"><span class="'.esc_attr($span_class).'"></span>',
				'after_title'   => '</h3>',
			) );			

			register_sidebar( array(
				'name'          => esc_html__( 'Footer 2', 'homefort' ),
				'id'            => 'footer-2',
				'description'   => esc_html__( 'Displayed in the footer section of the site.', 'homefort' ),
				'before_widget' => '<div id="%1$s" class="widget %2$s">',
				'after_widget'  => '</div>',
				'before_title'  => '<h3 class="lte-header-widget '.esc_attr($header_class).'"><span class="'.esc_attr($span_class).'"></span>',
				'after_title'   => '</h3>',
			) );			

			register_sidebar( array(
				'name'          => esc_html__( 'Footer 3', 'homefort' ),
				'id'            => 'footer-3',
				'description'   => esc_html__( 'Displayed in the footer section of the site.', 'homefort' ),
				'before_widget' => '<div id="%1$s" class="widget %2$s">',
				'after_widget'  => '</div>',
				'before_title'  => '<h3 class="lte-header-widget '.esc_attr($header_class).'"><span class="'.esc_attr($span_class).'"></span>',
				'after_title'   => '<span class="last '.esc_attr($span_class).'"></span></h3>',
			) );			

			register_sidebar( array(
				'name'          => esc_html__( 'Footer 4', 'homefort' ),
				'id'            => 'footer-4',
				'description'   => esc_html__( 'Displayed in the footer section of the site.', 'homefort' ),
				'before_widget' => '<div id="%1$s" class="widget %2$s">',
				'after_widget'  => '</div>',
				'before_title'  => '<h3 class="lte-header-widget '.esc_attr($header_class).'"><span class="'.esc_attr($span_class).'"></span>',
				'after_title'   => '</h3>',
			) );			
		}
			else {

			register_sidebar( array(
				'name'          => esc_html__( 'Footer', 'homefort' ),
				'id'            => 'footer-1',
				'description'   => esc_html__( 'Displayed in the footer section of the site.', 'homefort' ),
				'before_widget' => '<div id="%1$s" class="widget %2$s">',
				'after_widget'  => '</div>',
				'before_title'  => '<h3 class="lte-header-widget '.esc_attr($header_class).'"><span class="'.esc_attr($span_class).'"></span>',
				'after_title'   => '</h3>',
			) );
		}
	}
}



/**
 * Additional styles init
 */
if ( !function_exists('homefort_css_style') ) {

	add_action( 'wp_enqueue_scripts', 'homefort_css_style', 10 );
	function homefort_css_style() {

		global $wp_query;

		wp_enqueue_style( 'bootstrap', get_template_directory_uri() . '/assets/css/bootstrap-grid.css', array(), '1.0' );

		wp_enqueue_style( 'homefort-theme-style', get_stylesheet_uri(), array( 'bootstrap' ), wp_get_theme()->get('Version') );
	}
}



/**
 * Wp-admin styles and scripts
 */
if ( !function_exists('homefort_admin_init') ) {

	add_action( 'after_setup_theme', 'homefort_admin_init' );
	function homefort_admin_init() {

		add_action("admin_enqueue_scripts", 'homefort_admin_scripts');
	}

	function homefort_admin_scripts() {

		if ( function_exists('fw_get_db_settings_option') ) {

			homefort_get_fontello_generate(true);
			
			wp_enqueue_script( 'homefort-theme-admin', get_template_directory_uri() . '/assets/js/scripts-admin.js', array( 'jquery' ) );
		}
	}
}



